==> SmartNqData-0.1.4-py3-none-any.whl: SmartNqData/api_client.py <==
# SmartNqData/api_client.py

import requests
import pandas as pd
from datetime import datetime
import pytz
from .utils import is_valid_timeframe, format_indicator
from .enums import Timeframe

class SmartNqClient:
    def __init__(self, base_url):
        self.base_url = base_url
        self.est = pytz.timezone('US/Eastern')

    def GetFutureData(self, contract_symbol, start_datetime, end_datetime, timeframe, indicators):
        if not all(is_valid_timeframe(timeframe, indicator_timeframe) for indicator_timeframe in indicators.values()):
            raise ValueError("Indicator timeframe must be less granular than the main requested timeframe.")
        
        formatted_indicators = [format_indicator(ind, tf, timeframe) for ind, tf in indicators.items()]
        
        payload = {
            "contractSymbol": contract_symbol,
            "startDateTime": start_datetime,
            "endDateTime": end_datetime,
            "timeframe": timeframe.value,
            "requestedIndicators": formatted_indicators
        }

        response = requests.post(f'{self.base_url}/api/Data/query', json=payload)
        response.raise_for_status()

        data = response.json()
        
        candles = data['candles']
        formatted_data = []

        for candle in candles:
            row = {
                'Time': datetime.fromtimestamp(candle['t'], self.est),
                'Open': candle['o'],
                'High': candle['h'],
                'Low': candle['l'],
                'Close': candle['c'],
                'Volume': candle['v']
            }
            row.update(candle['i'])
            formatted_data.append(row)

        df = pd.DataFrame(formatted_data)

        return df

==> SmartNqData-0.1.7-py3-none-any.whl: SmartNqData/api_client.py <==
# SmartNqData/api_client.py

import requests
import pandas as pd
from datetime import datetime
import pytz
from .utils import is_valid_timeframe, format_indicator
from .enums import Timeframe, Indicator

class SmartNqClient:
    def __init__(self, base_url, api_key):
        self.base_url = base_url
        self.api_key = api_key
        self.est = pytz.timezone('US/Eastern')

    def GetFutureData(self, contract_symbol, start_datetime, end_datetime, timeframe, indicators):
        if not all(is_valid_timeframe(timeframe, indicator_timeframe) for indicator_timeframe in indicators.values()):
            raise ValueError("Indicator timeframe must be less granular than the main requested timeframe.")
        
        formatted_indicators = [format_indicator(ind, tf, timeframe) for ind, tf in indicators.items()]
        
        payload = {
            "contractSymbol": contract_symbol,
            "startDateTime": start_datetime,
            "endDateTime": end_datetime,
            "timeframe": timeframe.value,
            "requestedIndicators": formatted_indicators
        }

        headers = {
            'x-api-key': self.api_key
        }

        response = requests.post(f'{self.base_url}/api/Data/query', json=payload, headers=headers)
        response.raise_for_status()

        data = response.json()
        
        candles = data['candles']
        formatted_data = []

        for candle in candles:
            # Convert to Eastern Time and then to naive datetime
            naive_time = datetime.fromtimestamp(candle['t'], self.est).replace(tzinfo=None)
            row = {
                'Time': naive_time,
                'Open': candle['o'],
                'High': candle['h'],
                'Low': candle['l'],
                'Close': candle['c'],
                'Volume': candle['v']
            }
            row.update(candle['i'])
            formatted_data.append(row)

        df = pd.DataFrame(formatted_data)

        return df
